PanelyController class

Mixed-in types

Constructors

PanelyController()

Properties

breadCumbsData → List<Map<String, dynamic>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isFirstPageActive → bool
no setter
latefinal
panelTitle → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sidebarConfiguration → PanelySidebarConfiguration
no setter
theme → PanelyTheme
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
closeDialog<T extends Object?>([T? result]) → void
dispose() → void
Discards any resources used by the object.
inherited
init(BuildContext context, {required PanelySidebarConfiguration sidebarConfiguration, required String panelTitle, required PanelyTheme theme, required BasePanelyContentPage startPage, required String pageTitle}) → dynamic
isPageActive(BasePanelyContentPage page) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setNewRoute(BasePanelyContentPage page) → void
showConfirmationDialg(BuildContext context, {required String title, required String description, PanelyButtonType cancelButtonType = PanelyButtonType.secondary, String cancelButtonText = "Cancel", PanelyButtonType actionButtonType = PanelyButtonType.primary, String actionButtonText = "Do magic!", required dynamic actionButtonOnPress(), Size? size}) → void
showCustomDialg({required String title, String? description, Size? size, required Widget child, required List<PanelyButton> actions}) → void
showInformationDialg({required String title, required String description, PanelyButtonType buttonType = PanelyButtonType.primary, String buttonText = "Ok", Size? size}) → void
showNotification({required PanelyNotificationType type, required String title, String? description, dynamic autoCloseDuration = const Duration(seconds: 5)}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited